package com.liquidnet.service.kylin.controller.admin;

import com.liquidnet.service.ResponseDto;
import com.liquidnet.service.kylin.dao.FieldMisListDao;
import com.liquidnet.service.kylin.dto.param.FieldsParam;
import com.liquidnet.service.kylin.dto.param.FieldsSearchParam;
import com.liquidnet.service.kylin.dto.vo.FieldsMisListVo;
import com.liquidnet.service.kylin.dto.vo.FieldsVo;
import com.liquidnet.service.kylin.dto.vo.PagerVo;
import com.liquidnet.service.kylin.service.impl.FieldsServiceImpl;
import com.liquidnet.service.kylin.service.impl.admin.FieldsAdminServiceImpl;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;

@Api
@RestController
@RequestMapping("/admin/fields")
public class FieldsAdminController {

    @Autowired
    private FieldsAdminServiceImpl fieldsAdminService;

    @PostMapping(value = "")
    @ApiOperation(value = "创建场地")
    @ApiResponse(response = FieldsVo.class, code = 200, message = "接口返回对象参数")
    public ResponseDto<FieldsVo> createFields(@RequestBody FieldsParam fieldsParam) {
        boolean result = fieldsAdminService.fieldCreate(fieldsParam);
        if (result) {
            return ResponseDto.success();
        } else {
            return ResponseDto.failure("场地创建失败");
        }
    }

    @PutMapping(value = "")
    @ApiOperation(value = "mis修改场地全部数据")
    @ApiResponse(response = FieldsVo.class, code = 200, message = "接口返回对象参数")
    public ResponseDto<FieldsVo> fieldUpdate(@RequestBody FieldsParam fieldsParam) {
        boolean result = fieldsAdminService.fieldUpdateMessage(fieldsParam);
        if (result) {
            return ResponseDto.success();
        } else {
            return ResponseDto.failure("修改场地失败");
        }
    }

    @PostMapping(value = "list")
    @ApiOperation(value = "mis获取场地列表")
    @ApiResponse(response = PagerVo.class, code = 200, message = "接口返回对象参数")
    public ResponseDto<PagerVo<FieldMisListDao>> fieldList(@RequestBody FieldsSearchParam fieldsSearchParam) {
        List<FieldMisListDao> result = fieldsAdminService.fieldList(fieldsSearchParam);
        Long total = fieldsAdminService.fieldListCount(fieldsSearchParam);

        PagerVo<FieldMisListDao> pagerVo = new PagerVo();
        pagerVo.setRows(result);
        pagerVo.setTotal(total);

        if (pagerVo.getRows().size() > 0) {
            return ResponseDto.success(pagerVo);
        } else {
            return ResponseDto.failure("获取列表失败");
        }
    }
}
